-- version and date
local revision = tonumber(("$Revision: 62333 $"):match("%d+"))
if not NSD_REVISION or revision > NSD_REVISION then
    NSD_REVISION = revision
    NSD_DATE = ("$Date: 2008-02-21 02:00:03 -0500 (Thu, 21 Feb 2008) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

-- localisations
local L = AceLibrary("AceLocale-2.2"):new("ShakedownQuartz")
L:RegisterTranslations("enUS", function() return {
    ["Quartz"] = true,
} end)

-- create the class
local AceOO = AceLibrary("AceOO-2.0")
Addon = AceOO.Class(ShakedownAddonBase)

-- constructor
function Addon.prototype:init()
    Addon.super.prototype.init(self, "Quartz", L["Quartz"])
end

function Addon.prototype:Activate()

    if not Addon.super.prototype.Activate(self) then return end
    
    -- show each of the free bars by calling the "unlock" function
    local player = Quartz.options.args.Player
    if Quartz:IsModuleActive("Player", true) and player then
        player.args.lock.set(false)
        -- hide the standard UI bits
        local castbarCoveringFrame = getglobal("castbarCoveringFrame")
        if castbarCoveringFrame then
            castbarCoveringFrame:Hide()
        end
    end
    local focus = Quartz.options.args.Focus
    if Quartz:IsModuleActive("Focus", true) and focus then
        focus.args.lock.set(false)
    end
    local target = Quartz.options.args.Target
    if Quartz:IsModuleActive("Target", true) and target then
        target.args.lock.set(false)
    end
    local pet = Quartz.options.args.Pet
    if Quartz:IsModuleActive("Pet", true) and pet then
        pet.args.lock.set(false)
    end
    
    -- show the buff bars only if they are free
    local buff = Quartz.options.args.Buff
    if Quartz:IsModuleActive("Buff", true) and buff then
        local db = Quartz:AcquireDBNamespace("Buff")
        if db.profile.focusanchor == "Free" then
            buff.args.focus.args.focuslock.set(false)
        end
        if db.profile.targetanchor == "Free" then
            buff.args.target.args.targetlock.set(false)
        end
    end
    
    -- show the mirror bar if it is free
    local mirror = Quartz.options.args.Mirror
    if Quartz:IsModuleActive("Mirror", true) and mirror then
        if Quartz:AcquireDBNamespace("Mirror").profile.mirroranchor == "Free" then
            mirror.args.mirrorlock.set(false)
        end
        -- hide the standard UI bits
        for i = 1, 3 do
            local mirrorCoveringFrame = getglobal("mirrorCoveringFrame"..i)
            if mirrorCoveringFrame then
                mirrorCoveringFrame:Hide()
            end
        end
    end
    
    -- show the swing bar if it is free
    local swing = Quartz.options.args.Swing
    if Quartz:IsModuleActive("Swing", true) and swing then
        if Quartz:AcquireDBNamespace("Swing").profile.swingposition == "Free" then
            swing.args.lock.set(false)
        end
    end
end

function Addon.prototype:Deactivate()

    Addon.super.prototype.Deactivate(self)

    -- hide each of the free bars
    local player = Quartz.options.args.Player
    if Quartz:IsModuleActive("Player", true) and player then
        player.args.lock.set(true)
    end
    local focus = Quartz.options.args.Focus
    if Quartz:IsModuleActive("Focus", true) and focus then
        focus.args.lock.set(true)
    end
    local target = Quartz.options.args.Target
    if Quartz:IsModuleActive("Target", true) and target then
        target.args.lock.set(true)
    end
    local pet = Quartz.options.args.Pet
    if Quartz:IsModuleActive("Pet", true) and pet then
        pet.args.lock.set(true)
    end
    
    -- hide the buff bars only if they are free
    local buff = Quartz.options.args.Buff
    if Quartz:IsModuleActive("Buff", true) and buff then
        local db = Quartz:AcquireDBNamespace("Buff")
        if db.profile.focusanchor == "Free" then
            buff.args.focus.args.focuslock.set(true)
        end
        if db.profile.targetanchor == "Free" then
            buff.args.target.args.targetlock.set(true)
        end
    end
    
    -- hide the mirror bar if it is free
    local mirror = Quartz.options.args.Mirror
    if Quartz:IsModuleActive("Mirror", true) and mirror then
        if Quartz:AcquireDBNamespace("Mirror").profile.mirroranchor == "Free" then
            mirror.args.mirrorlock.set(true)
        end
    end

    -- hide the swing bar if it is free
    local swing = Quartz.options.args.Swing
    if Quartz:IsModuleActive("Swing", true) and swing then
        if Quartz:AcquireDBNamespace("Swing").profile.swingposition == "Free" then
            swing.args.lock.set(true)
        end
    end
end                        

-- create the instance of this class; parent's constructor will handle registration with the main shakedown code
local thisAddon = Addon:new()